var NAVTREEINDEX18 =
{
"page_configuration.html#config_stream_args_args":[0,0,3,2,2],
"page_configuration.html#config_stream_args_channels":[0,0,3,2,3],
"page_configuration.html#config_stream_args_cpu_format":[0,0,3,2,0],
"page_configuration.html#config_stream_args_otw_format":[0,0,3,2,1],
"page_configuration.html#config_stream_args_transport":[0,0,3,2,2,0],
"page_configuration.html#config_subdev":[0,0,3,1],
"page_configuration.html#config_subdev_dbnames":[0,0,3,1,2],
"page_configuration.html#config_subdev_default":[0,0,3,1,1],
"page_configuration.html#config_subdev_slotnames":[0,0,3,1,0],
"page_converters.html":[0,1,4],
"page_converters.html#converters_accel":[0,1,4,2],
"page_converters.html#converters_formats":[0,1,4,1],
"page_converters.html#converters_formats_internal":[0,1,4,1,0],
"page_converters.html#converters_overview":[0,1,4,0],
"page_converters.html#converters_register":[0,1,4,3],
"page_converters.html#converters_register_extra":[0,1,4,3,0],
"page_converters.html#converters_register_internal":[0,1,4,3,1],
"page_dboards.html":[0,0,23],
"page_dboards.html#dboards":[0,0,23,0],
"page_dboards.html#dboards_basicrx":[0,0,23,0,0],
"page_dboards.html#dboards_basictx":[0,0,23,0,1],
"page_dboards.html#dboards_cbx":[0,0,23,0,8],
"page_dboards.html#dboards_clock_rate":[0,0,23,0,18],
"page_dboards.html#dboards_dbsrx":[0,0,23,0,2],
"page_dboards.html#dboards_dbsrx2":[0,0,23,0,3],
"page_dboards.html#dboards_dbsrxmod":[0,0,23,0,19],
"page_dboards.html#dboards_dbsrxmod_1":[0,0,23,0,19,0],
"page_dboards.html#dboards_dbsrxmod_2":[0,0,23,0,19,1],
"page_dboards.html#dboards_e300":[0,0,23,0,14],
"page_dboards.html#dboards_fbx":[0,0,23,0,17],
"page_dboards.html#dboards_n310":[0,0,23,0,15],
"page_dboards.html#dboards_obx":[0,0,23,0,10],
"page_dboards.html#dboards_rfx":[0,0,23,0,4],
"page_dboards.html#dboards_rfxmod":[0,0,23,0,20],
"page_dboards.html#dboards_sbx":[0,0,23,0,7],
"page_dboards.html#dboards_tvrx":[0,0,23,0,12],
"page_dboards.html#dboards_tvrx2":[0,0,23,0,13],
"page_dboards.html#dboards_twinrx":[0,0,23,0,11],
"page_dboards.html#dboards_ubx":[0,0,23,0,9],
"page_dboards.html#dboards_wbx":[0,0,23,0,6],
"page_dboards.html#dboards_xcvr":[0,0,23,0,5],
"page_dboards.html#dboards_zbx":[0,0,23,0,16],
"page_devices.html":[0,0],
"page_devices.html#autotoc_md0":[0,0],
"page_devices.html#autotoc_md1":[0,1],
"page_devices.html#autotoc_md2":[0,2],
"page_devices.html#autotoc_md3":[0,3],
"page_devices.html#autotoc_md4":[0,4],
"page_devices.html#autotoc_md5":[0,5],
"page_devices.html#autotoc_md6":[0,6],
"page_devices.html#autotoc_md7":[0,7],
"page_devices.html#autotoc_md8":[0,8],
"page_dpdk.html":[0,0,11],
"page_dpdk.html#dpdk_device_args":[0,0,11,2,0],
"page_dpdk.html#dpdk_installation":[0,0,11,1,0],
"page_dpdk.html#dpdk_link_detection":[0,0,11,2,1],
"page_dpdk.html#dpdk_nic_config":[0,0,11,1,2],
"page_dpdk.html#dpdk_overview":[0,0,11,0],
"page_dpdk.html#dpdk_setup":[0,0,11,1],
"page_dpdk.html#dpdk_system_configuration":[0,0,11,1,1],
"page_dpdk.html#dpdk_troubleshooting":[0,0,11,2,2],
"page_dpdk.html#dpdk_using":[0,0,11,2],
"page_extension.html":[0,0,15],
"page_extension.html#extension_capabilities":[0,0,15,1],
"page_extension.html#extension_howto":[0,0,15,1,0],
"page_extension.html#extension_intro":[0,0,15,0],
"page_fbx.html":[0,0,23,3],
"page_fbx.html#fbx_antenna":[0,0,23,3,3],
"page_fbx.html#fbx_atr":[0,0,23,3,5],
"page_fbx.html#fbx_leds":[0,0,23,3,3,0],
"page_fbx.html#fbx_overview":[0,0,23,3,0],
"page_fbx.html#fbx_sensors":[0,0,23,3,4],
"page_fbx.html#fbx_too":[0,0,23,3,1],
"page_fbx.html#fbx_too_dctrl":[0,0,23,3,2],
"page_general.html":[0,0,1],
"page_general.html#general_misc":[0,0,1,4],
"page_general.html#general_misc_dynamic":[0,0,1,4,0],
"page_general.html#general_misc_prints":[0,0,1,4,1],
"page_general.html#general_ounotes":[0,0,1,2],
"page_general.html#general_ounotes_overflow":[0,0,1,2,0],
"page_general.html#general_ounotes_underrun":[0,0,1,2,1],
"page_general.html#general_sampleratenotes":[0,0,1,1],
"page_general.html#general_sampleratenotes_automatic":[0,0,1,1,0],
"page_general.html#general_sampleratenotes_nyquist":[0,0,1,1,1],
"page_general.html#general_threading":[0,0,1,3],
"page_general.html#general_threading_prio":[0,0,1,3,1],
"page_general.html#general_threading_safety":[0,0,1,3,0],
"page_general.html#general_tuning":[0,0,1,0],
"page_general.html#general_tuning_dsp":[0,0,1,0,1],
"page_general.html#general_tuning_dsp_sign":[0,0,1,0,2],
"page_general.html#general_tuning_multiplechannels":[0,0,1,0,4],
"page_general.html#general_tuning_process":[0,0,1,0,0],
"page_general.html#general_tuning_rfsettling":[0,0,1,0,3],
"page_general.html#general_tuning_rxchain":[0,0,1,0,0,0],
"page_general.html#general_tuning_waitcode":[0,0,1,0,3,0],
"page_gpio_api.html":[0,0,19,14],
"page_gpio_api.html#autotoc_md10":[0,0,19,14,0,2,0],
"page_gpio_api.html#autotoc_md9":[0,0,19,14,0,1,1],
"page_gpio_api.html#e320_gpio_conn":[0,0,19,14,0,2],
"page_gpio_api.html#egpio_internal_conn":[0,0,19,14,0,1,0],
"page_gpio_api.html#egpio_internal_gpio":[0,0,19,14,0,1],
"page_gpio_api.html#xgpio_fpanel":[0,0,19,14,0],
"page_gpio_api.html#xgpio_fpanel_atr":[0,0,19,14,0,3],
"page_gpio_api.html#xgpio_fpanel_conn":[0,0,19,14,0,0,0],
"page_gpio_api.html#xgpio_fpanel_gpio":[0,0,19,14,0,0],
"page_gpio_api.html#xgpio_fpanel_pins":[0,0,19,14,0,0,1],
"page_gpio_api.html#xgpio_fpanel_xample":[0,0,19,14,0,4],
"page_gpsdo.html":[0,0,16,10],
"page_gpsdo.html":[0,0,22,6],
"page_gpsdo.html#gpsdo_install":[0,0,16,10,1],
"page_gpsdo.html#gpsdo_install":[0,0,22,6,1],
"page_gpsdo.html#gpsdo_specs":[0,0,16,10,0],
"page_gpsdo.html#gpsdo_specs":[0,0,22,6,0],
"page_gpsdo.html#gpsdo_use":[0,0,16,10,2],
"page_gpsdo.html#gpsdo_use":[0,0,22,6,2],
"page_gpsdo.html#gspdo_install_post":[0,0,16,10,1,0],
"page_gpsdo.html#gspdo_install_post":[0,0,22,6,1,0],
"page_gpsdo_b2x0.html":[0,0,17,9],
"page_gpsdo_b2x0.html#gpsdob_install":[0,0,17,9,1],
"page_gpsdo_b2x0.html#gpsdob_power":[0,0,17,9,3],
"page_gpsdo_b2x0.html#gpsdob_specs":[0,0,17,9,0],
"page_gpsdo_b2x0.html#gpsdob_using":[0,0,17,9,2],
"page_gpsdo_x3x0.html":[0,0,19,13],
"page_gpsdo_x3x0.html#gpsdox_custom_cmds":[0,0,19,13,2,2],
"page_gpsdo_x3x0.html#gpsdox_install":[0,0,19,13,1],
"page_gpsdo_x3x0.html#gpsdox_sensors":[0,0,19,13,2,1],
"page_gpsdo_x3x0.html#gpsdox_setting_gps_time":[0,0,19,13,2,0],
"page_gpsdo_x3x0.html#gpsdox_specs":[0,0,19,13,0],
"page_gpsdo_x3x0.html#gpsdox_using":[0,0,19,13,2],
"page_identification.html":[0,0,2],
"page_identification.html#id_identifying":[0,0,2,0],
"page_identification.html#id_identifying_api":[0,0,2,0,2],
"page_identification.html#id_identifying_cmdline":[0,0,2,0,1],
"page_identification.html#id_identifying_common":[0,0,2,0,0],
"page_identification.html#id_identifying_props":[0,0,2,0,3],
"page_identification.html#id_naming":[0,0,2,1],
"page_identification.html#id_naming_discovery":[0,0,2,1,1],
"page_identification.html#id_naming_set":[0,0,2,1,0],
"page_images.html":[0,0,5],
"page_images.html#images_building":[0,0,5,2],
"page_images.html#images_building_altera":[0,0,5,2,2],
"page_images.html#images_building_fx2":[0,0,5,2,3],
"page_images.html#images_building_xilinx":[0,0,5,2,0],
"page_images.html#images_building_zpu":[0,0,5,2,1],
"page_images.html#images_overview":[0,0,5,0],
"page_images.html#images_prebuild":[0,0,5,1],
"page_images.html#images_prebuilt_archive":[0,0,5,1,2],
"page_images.html#images_prebuilt_downloader":[0,0,5,1,0],
"page_images.html#images_prebuilt_installers":[0,0,5,1,1],
"page_install.html":[0,3],
"page_install.html#Troubleshooting":[0,3,0,2,0],
"page_install.html#install_libUSB":[0,3,0,3],
"page_install.html#install_linux":[0,3,1],
"page_install.html#install_linux_ourbins":[0,3,1,1],
"page_install.html#install_linux_ourbins_fedora":[0,3,1,1,1],
"page_install.html#install_linux_ourbins_ubuntu":[0,3,1,1,0],
"page_install.html#install_linux_pkgmgr":[0,3,1,0],
"page_install.html#install_linux_pybombs":[0,3,1,2],
"page_install.html#install_osx":[0,3,2],
"page_install.html#install_osx_macports":[0,3,3],
"page_install.html#install_win":[0,3,0],
"page_install.html#install_win_installer":[0,3,0,1],
"page_install.html#install_win_libusb":[0,3,0,0],
"page_install.html#install_win_post":[0,3,0,1,0],
"page_install.html#install_win_python":[0,3,0,2],
"page_install.html#install_win_source":[0,3,0,4],
"page_logging.html":[0,1,8],
"page_logging.html#logging_backends":[0,1,8,2],
"page_logging.html#logging_levels":[0,1,8,0],
"page_logging.html#logging_macros":[0,1,8,1],
"page_mpm.html":[0,0,10],
"page_mpm.html#mpm_arch":[0,0,10,0],
"page_mpm.html#mpm_arch_claiming":[0,0,10,1],
"page_mpm.html#mpm_debug":[0,0,10,3],
"page_mpm.html#mpm_debug_other":[0,0,10,3,1],
"page_mpm.html#mpm_debug_python":[0,0,10,3,0],
"page_mpm.html#mpm_modes":[0,0,10,2],
"page_mpm.html#mpm_shell_hijack":[0,0,10,4],
"page_multiple.html":[0,0,4],
"page_multiple.html#multiple_channumbers":[0,0,4,2],
"page_multiple.html#multiple_intro":[0,0,4,0],
"page_multiple.html#multiple_mimo":[0,0,4,3],
"page_multiple.html#multiple_setup":[0,0,4,1],
"page_ni_rio_kernel.html":[0,0,19,16],
"page_ni_rio_kernel.html#linux_enabling":[0,0,19,16,0,3],
"page_ni_rio_kernel.html#linux_installation":[0,0,19,16,0,2],
"page_ni_rio_kernel.html#linux_overview":[0,0,19,16,0,0],
"page_ni_rio_kernel.html#linux_requirements":[0,0,19,16,0,1],
"page_ni_rio_kernel.html#linux_rio":[0,0,19,16,0],
"page_ni_rio_kernel.html#linux_swapping":[0,0,19,16,0,4],
"page_ni_rio_kernel.html#linux_uninstalling":[0,0,19,16,0,6],
"page_ni_rio_kernel.html#linux_upgrades":[0,0,19,16,0,5],
"page_ni_rio_kernel.html#win_enabling":[0,0,19,16,1,2],
"page_ni_rio_kernel.html#win_install":[0,0,19,16,1,1],
"page_ni_rio_kernel.html#win_requirements":[0,0,19,16,1,0],
"page_ni_rio_kernel.html#win_swapping":[0,0,19,16,1,3],
"page_ni_rio_kernel.html#win_uninstall":[0,0,19,16,1,4],
"page_ni_rio_kernel.html#windows_rio":[0,0,19,16,1],
"page_octoclock.html":[0,0,24],
"page_octoclock.html#boot_process":[0,0,24,3,0],
"page_octoclock.html#bootloader":[0,0,24,2,1],
"page_octoclock.html#detecting_new_unit":[0,0,24,1],
"page_octoclock.html#eeprom":[0,0,24,2,3],
"page_octoclock.html#firmware":[0,0,24,2,2],
"page_octoclock.html#front_panel_leds":[0,0,24,3,2],
"page_octoclock.html#getting_latest":[0,0,24,2,0],
"page_octoclock.html#octoclock_features":[0,0,24,0],
"page_octoclock.html#selecting":[0,0,24,3,1],
"page_octoclock.html#uhd":[0,0,24,3,3],
"page_octoclock.html#upgrading_device":[0,0,24,2],
"page_octoclock.html#usage":[0,0,24,3],
"page_power.html":[0,0,14],
"page_power.html#power_amp_rate":[0,0,14,2],
"page_power.html#power_cal_switch":[0,0,14,6,0],
"page_power.html#power_implementation":[0,0,14,4],
"page_power.html#power_overview":[0,0,14,0],
"page_power.html#power_ref_levels":[0,0,14,1],
"page_power.html#power_storage":[0,0,14,5],
"page_power.html#power_tune_owner":[0,0,14,3],
"page_power.html#power_usercal":[0,0,14,6],
"page_power.html#power_usercal_extend":[0,0,14,6,1],
"page_power.html#power_usercal_extend_generic":[0,0,14,6,1,1],
"page_power.html#power_usercal_extend_visa":[0,0,14,6,1,0],
"page_properties.html":[1],
"page_properties.html#props_common_props":[1,7],
"page_properties.html#props_define":[1,3],
"page_properties.html#props_graph_resolution":[1,5],
"page_properties.html#props_graph_resolution_back_edges":[1,5,0],
"page_properties.html#props_intro":[1,0],
"page_properties.html#props_multichan":[1,2],
"page_properties.html#props_propprop":[1,1],
"page_properties.html#props_resolvers":[1,4],
"page_properties.html#props_resolvers_cldrty":[1,4,0],
"page_properties.html#props_special_props":[1,8],
"page_properties.html#props_special_props_mtu":[1,10],
"page_properties.html#props_special_props_tickrate":[1,9],
"page_properties.html#props_unknown":[1,6],
"page_python.html":[0,1,2],
"page_python.html#python_install":[0,1,2,0],
"page_python.html#python_install_adv":[0,1,2,0,1],
"page_python.html#python_install_windows":[0,1,2,0,0],
"page_python.html#python_usage":[0,1,2,1],
"page_python.html#python_usage_gil":[0,1,2,3],
"page_python.html#python_usage_oneoff":[0,1,2,2],
"page_rdtesting.html":[0,1,9],
"page_rdtesting.html#autotoc_md14":[0,1,9,1,1,0],
"page_rdtesting.html#autotoc_md15":[0,1,9,1,1,1],
"page_rdtesting.html#autotoc_md28":[0,1,9,4,2,0],
"page_rdtesting.html#autotoc_md29":[0,1,9,4,2,0,0],
"page_rdtesting.html#autotoc_md30":[0,1,9,4,2,0,1]
};
